@@ -1,5 +1,5 @@
-from VirtualKey.ctypes_key import PressKey, ReleaseKey
-from bd_time import vk, tt
+from .ctypes_key import PressKey, ReleaseKey
+from bdtime import vk, tt
 
 # press any ch
 def down_up(ch, t = 0.5):
